@@ -1,11 +1,11 @@
 # -*- encoding: utf-8 -*-
 """
- $Id: Lib.py,v 1.11.2.7 2009/06/09 18:39:06 customdesigned Exp $
+ $Id: Lib.py,v 1.11.2.7.2.2 2011/03/23 01:42:07 customdesigned Exp $
 
  This file is part of the pydns project.
  Homepage: http://pydns.sourceforge.net
 
- This code is covered by the standard Python License.
+ This code is covered by the standard Python License. See LICENSE for details.
 
  Library code. Largely this is packers and unpackers for various types.
 """
@@ -713,6 +713,12 @@ if __name__ == "__main__":
     testpacker()
 #
 # $Log: Lib.py,v $
+# Revision 1.11.2.7.2.2  2011/03/23 01:42:07  customdesigned
+# Changes from 2.3 branch
+#
+# Revision 1.11.2.7.2.1  2011/02/18 19:35:22  customdesigned
+# Python3 updates from Scott Kitterman
+#
 # Revision 1.11.2.7  2009/06/09 18:39:06  customdesigned
 # Built-in SPF support
 #
